Crate web_transport_ws

Crate web_transport_ws 

Deprecated

This crate has been superseded by the qmux crate, which supports TCP, TLS, and WebSocket transports with both the legacy webtransport wire format and the new QMux (draft-ietf-quic-qmux-00) protocol.

All Rust types in this crate are thin wrappers or re-exports from qmux. Please migrate to qmux directly.

Re-exports

pub use tokio_tungstenite;
pub use tokio_tungstenite::tungstenite;

Structs

ClientDeprecated
A WebTransport client that connects over WebSocket.
RecvStream
The receive half of a multiplexed stream.
SendStream
The send half of a multiplexed stream.
ServerDeprecated
A WebTransport server that accepts WebSocket connections.
SessionDeprecated
A WebTransport session over WebSocket.

Enums

Error
Errors that can occur during QMux session and stream operations.

Constants

ALPNDeprecated
Legacy ALPN identifier.