Deprecated
This crate has been superseded by the qmux crate, which supports
TCP, TLS, and WebSocket transports with both the legacy webtransport
wire format and the new QMux (draft-ietf-quic-qmux-00) protocol.
All Rust types in this crate are thin wrappers or re-exports from qmux.
Please migrate to qmux directly.
Re-exports
pub use tokio_tungstenite;pub use tokio_tungstenite::tungstenite;
Structs
- Client
Deprecated - A WebTransport client that connects over WebSocket.
- Recv
Stream - The receive half of a multiplexed stream.
- Send
Stream - The send half of a multiplexed stream.
- Server
Deprecated - A WebTransport server that accepts WebSocket connections.
- Session
Deprecated - A WebTransport session over WebSocket.
Enums
- Error
- Errors that can occur during QMux session and stream operations.
Constants
- ALPN
Deprecated - Legacy ALPN identifier.